@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11880 2020-01-19 11:50:00Z Lavender $
+# $Id: __init__.py 11894 2020-02-04 12:08:11Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-01-19 19:50:00 +0800 (週日, 19 一月 2020) $
-# $Revision: 11880 $
+# $Date: 2020-02-04 21:08:11 +0900 (週二, 04 二月 2020) $
+# $Revision: 11894 $
 
 import os
 import sys
@@ -32,7 +32,7 @@ import twder
 
 from Iuppiter.Encoding import utf8
 from Iuppiter.Encryption import Encryptor
-from Iuppiter.DjangoUtil import DJANGO_VERSION
+from Iuppiter.DjangoUtil import DJANGO_VERSION, reverse
 from Iuno import warnWithout, update, require
 from Iuppiter.DjangoUtil import (extendInstalledApps, 
                                  extendMiddlewareClasses, 
@@ -44,11 +44,6 @@ from Iuppiter.DjangoUtil import (extendInstalledApps,
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ugettext as _2
 
-if DJANGO_VERSION <= 20000: # 2.0.0:
-    from django.core.urlresolvers import reverse
-else:
-    from django.urls import reverse
-
 from Iuno.Patch import patterns
 
 from Iuppiter.Logging import createLogger
@@ -393,6 +388,8 @@ def attachSettings(settingsDict, enablePaypal=False):
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('Paypal transactions'),
             'url_name': 'paypal-express-list',
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
 
     if ecpayEnable:
@@ -1188,6 +1185,9 @@ def buildAPIForm(submission, request, apiName, extra={}):
             formData = encryptor.encrypt(form)
         
         form = base64.b64encode(formData)
+        
+        if six.PY3:
+            form = form.decode()
             
         temp = get_template('shop/payment/PaymentForm.html')
         if DJANGO_VERSION >= 11100: # django >= 1.11
