@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11314 2018-12-14 05:31:25Z Kevin $
+# $Id: __init__.py 11724 2019-09-24 07:05:18Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $ (last)
-# $Date: 2018-12-14 13:31:25 +0800 (週五, 14 十二月 2018) $
-# $Revision: 11314 $
+# $Author: Lavender $ (last)
+# $Date: 2019-09-24 16:05:18 +0900 (週二, 24 九月 2019) $
+# $Revision: 11724 $
 
 import os
 
@@ -41,7 +41,7 @@ if hasattr(settings, "TEMPLATES"):
     except Exception as e:
         pass
 
-if not STATIC_DIR:
+if not TEMPLATE_DIR:
     TEMPLATE_DIR = os.path.join(settings.BASE_DIR, "templates")
 
 BACKUP_DIR_NAME = "_Iuno.template_editor_backup" 
